@@ -4,14 +4,15 @@ use strict;
 use Exporter;
 use DynaLoader;
 
-our $VERSION = '0.01';
+our $VERSION = '0.02';
 our @EXPORT_OK  = qw( Dump Load );
 our @ISA     = qw( Exporter DynaLoader );
 
 __PACKAGE__->bootstrap;
 
-$JSON::Syck::ImplicitTyping = 1;
-$JSON::Syck::Headless       = 1;
+$JSON::Syck::ImplicitTyping  = 1;
+$JSON::Syck::Headless        = 1;
+$JSON::Syck::ImplicitUnicode = 0;
 
 1;
 
@@ -41,12 +42,13 @@ JSON data representation.
 You might want to know the difference between I<JSON> and
 I<JSON::Syck>.
 
-While JSON is a pure-perl module and JSON::Syck is based on libsyck,
+Since JSON is a pure-perl module and JSON::Syck is based on libsyck,
 JSON::Syck is supposed to be very fast and memory efficient. See
-chansen's benchmark table at L<http://rafb.net/paste/results/8rSJGq74.txt>.
+chansen's benchmark table at
+L<http://idisk.mac.com/christian.hansen/Public/perl/serialize.pl>
 
 JSON.pm comes with dozens of ways to do the same thing and lots of
-options, while JSON::Syck doesn't. There's only C<Load> and C<Dump>
+options, while JSON::Syck doesn't. There's only C<Load> and C<Dump>.
 
 Oh, and JSON::Syck doesn't use camelCase method names :-)
 
@@ -63,10 +65,6 @@ The F<libsyck> code bundled with this module is written by I<why the
 lucky stiff>, under a BSD-style license.  See the F<COPYING> file for
 details.
 
-The F<Storable.xs> code bundled with this library is written by
-Raphael Manfredi and maintained by perl5-porters, under the same
-license as Perl.
-
 This program is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself.
 
